#
# spec file for package libcec
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Guillaume GARDET <guillaume@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover   4
%define libname	%{name}%{sover}
%bcond_with enable_rpi_build
Name:           libcec
Version:        4.0.2
Release:        lp150.2.1
Summary:        Control your device with your TV remote control via HDMI
License:        GPL-2.0-or-later
Group:          Hardware/TV
URL:            https://github.com/Pulse-Eight/libcec
Source:         https://github.com/Pulse-Eight/libcec/archive/libcec-%{version}.tar.gz
Patch1:         libcec-cmake_install_lib_dir.patch
Patch123:       libcec-build-compare.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  swig
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(lockdev)
BuildRequires:  pkgconfig(p8-platform)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(xrandr)
%ifarch armv6l armv6hl
%if %{with enable_rpi_build}
BuildRequires:  raspberrypi-gfx-devel
%endif
%endif

%description
libCEC allows you, in combination with the right hardware, to control
your device with your TV remote control utilizing your existing HDMI
cabling.

libCEC is an enabling platform for the CEC bus in HDMI, it allows
developers to interact with other HDMI devices without having to
worry about the communication overhead, handshaking, and the various
ways of sending a message for each vendor.

%package -n cec-client
Summary:        Control your device with your TV remote control via HDMI
Group:          Hardware/TV
Requires:       %{libname} = %{version}

%description -n cec-client
libCEC allows you, in combination with the right hardware, to control
your device with your TV remote control utilizing your existing HDMI
cabling.

libCEC is an enabling platform for the CEC bus in HDMI, it allows
developers to interact with other HDMI devices without having to
worry about the communication overhead, handshaking, and the various
ways of sending a message for each vendor.

This package contains client applications

%package -n python3-%{name}
Summary:        Python bindings for %{name}
Group:          Hardware/TV

%description -n python3-%{name}
libCEC allows you, in combination with the right hardware, to control
your device with your TV remote control utilizing your existing HDMI
cabling.

libCEC is an enabling platform for the CEC bus in HDMI, it allows
developers to interact with other HDMI devices without having to
worry about the communication overhead, handshaking, and the various
ways of sending a message for each vendor.

This package contains python bindings

%package -n %{libname}
Summary:        USB CEC adapter communication library
Group:          System/Libraries

%description -n %{libname}
libCEC allows you, in combination with the right hardware, to control
your device with your TV remote control utilizing your existing HDMI
cabling.

%package devel
Summary:        Development files for the USB CEC adapter communication library
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
libCEC is an enabling platform for the CEC bus in HDMI, it allows
developers to interact with other HDMI devices without having to
worry about the communication overhead, handshaking, and the various
ways of sending a message for each vendor.

This subpackage contains the headers for libcec.

%prep
%setup -q -n %{name}-%{name}-%{version}
%patch1
%patch123 -p1
sed -i "s|bin/python|bin/python3|g" src/pyCecClient/pyCecClient.py

%build
%cmake
%make_jobs

%install
%cmake_install

%post   -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n cec-client
%defattr(755,root,root)
%{_bindir}/cec-client
%{_bindir}/cec-client-%{version}
%{_bindir}/cecc-client
%{_bindir}/cecc-client-%{version}

%files -n python3-%{name}
%{_bindir}/pyCecClient
%{python3_sitearch}/*

%files -n %{libname}
%{_libdir}/libcec.so.%{sover}*

%files devel
%{_includedir}/libcec
%{_libdir}/pkgconfig/libcec.pc
%{_libdir}/libcec.so

%changelog
* Thu Mar  8 2018 mpluskal@suse.com
- Cleanup spec file
- Switch to python3
* Sun Feb 19 2017 sagiben@gmail.com
- Rebase libcec-cmake_install_lib_dir.patch
* Sun Feb 19 2017 mpluskal@suse.com
- Update to version 4.0.2:
  * don't automatically assume that an AVR is active in some
    situations
  * don't take Panasonic's vendor id when emulating an AVR
  * drm EDID parser not compiled in.
  * python: have Swig generate Python threading support
  * python: only pass unsigned
  * python: allow empty callback parameters
  * python: install demo app as executable
  * python: correct install path.
  * python: possible crash when passing an invalid callback
  * TransmitVolumeDown to use CEC_USER_CONTROL_CODE_VOLUME_DOWN.
  * HAVE_AOCEC_API missing in if in AdapterFactory.
  * env.h had 'ON' instead of '1' for some values
  * bAutoWakeAVR entry in libcec_configuration, which controls
    whether to automatically power on the avr or not when the
    source is activated.
  * iDoubleTapTimeoutMs replacing iDoubleTapTimeout50Ms. time is
    now in milliseconds
  * new AO CEC adapter.
  * compilation with full debugging enabled
  * handling of LG vendor command 0x0B.
  * return value wasn't checked correctly in
    CLibCEC::RegisterClient()
  * Raspberry Pi fixes for issues #252 and #191
* Mon Jan 25 2016 olaf@aepfle.de
- Reduce build-compare noise
  libcec-build-compare.patch
* Sat Jan 23 2016 mpluskal@suse.com
- Rename cmake_install_lib_dir.patch to
  libcec-cmake_install_lib_dir.patch
* Sat Jan 23 2016 sagiben@gmail.com
- Update to v3.1.0
- Add cmake_install_lib_dir.patch patch for better handling
  of libdir in .pc file and python packge installation path
- Update dependency to libp8-platform
* Sat Jan  2 2016 mpluskal@suse.com
- Fix path to libdir in .pc file (boo#960475)
* Mon Nov 16 2015 christof.hanke@induhviduals.de
- Explictly require package libcec by package cec-client since the
  library is loaded via dlopen.
* Sat Jul 18 2015 mpluskal@suse.com
- Update to 3.0.1
  * no upstream changelog provided
* Fri Jun 12 2015 mpluskal@suse.com
- Revert name change
- Use %%cmake macro
- Cleanup spec file with spec-cleaner
- Use url for source
- Fix non stanard changelog entry
- Split python package
- Update dependencies (add swig, drop autotools)
- libcec-no-buildtime.patch and configure.ac.diff were dropped by
  previous change
- Update name of source dir
* Mon Jun  1 2015 sagiben@gmail.com
- Update to v3.0.0
* Mon Feb  2 2015 olaf@aepfle.de
- Remove timestamps from binary to reduce build-compare noise
  libcec-no-buildtime.patch
* Thu Dec 25 2014 jengelh@inai.de
- Implement shared library packaging guidelines
* Wed Nov 26 2014 sagiben@gmail.com
- Update to v2.2.0
* Mon Sep 16 2013 guillaume@opensuse.org
- Remove old tar.gz from 2.1.1 version
* Tue Sep  3 2013 guillaume@opensuse.org
- Cleanup for submition to devel project:
  * clean section removed
  * --disable-static option added and remove libcec.la
  * make use of paralel build: "make %%{?_smp_mflags}"
* Mon Aug 26 2013 guillaume@opensuse.org
- Add '%%bcond_with enable_rpi_build' for armv6
* Mon Aug 26 2013 guillaume@opensuse.org
- Update to v2.1.3
* Thu Mar 21 2013 guillaume@opensuse.org
- Update to v2.1.1
* Tue Dec 11 2012 guillaume@opensuse.org
- Update to v2.0.5 (repacked version)
* Fri Oct 19 2012 guillaume@opensuse.org
- Initial Release (v2.0.4)
